@@ -2,9 +2,9 @@
 
 /* Metacity interface for talking to GTK+ UI module */
 
-/* 
+/*
  * Copyright (C) 2001 Havoc Pennington
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
@@ -14,7 +14,7 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
@@ -57,17 +57,13 @@ MetaUI* meta_ui_new (Display *xdisplay,
                      Screen  *screen);
 void    meta_ui_free (MetaUI *ui);
 
-void meta_ui_theme_get_frame_borders (MetaUI *ui,
-                                      MetaFrameType      type,
-                                      MetaFrameFlags     flags,
-                                      int               *top_height,
-                                      int               *bottom_height,
-                                      int               *left_width,
-                                      int               *right_width);
-void meta_ui_get_frame_geometry (MetaUI *ui,
-                                 Window frame_xwindow,
-                                 int *top_height, int *bottom_height,
-                                 int *left_width, int *right_width);
+void meta_ui_theme_get_frame_borders (MetaUI           *ui,
+                                      MetaFrameType     type,
+                                      MetaFrameFlags    flags,
+                                      MetaFrameBorders *borders);
+void meta_ui_get_frame_borders (MetaUI           *ui,
+                                Window            frame_xwindow,
+                                MetaFrameBorders *borders);
 Window meta_ui_create_frame_window (MetaUI *ui,
                                     Display *xdisplay,
                                     Visual *xvisual,
@@ -111,6 +107,9 @@ void meta_ui_set_frame_title (MetaUI *ui,
                               Window xwindow,
                               const char *title);
 
+void meta_ui_update_frame_style (MetaUI *ui,
+                                 Window  window);
+
 void meta_ui_repaint_frame (MetaUI *ui,
                             Window xwindow);
 
